#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.8.0
visibility:           public
id:                   rio-prettyprint-0.1.8.0-fkOTaxTD7BIHmfqCE2iLl
key:                  rio-prettyprint-0.1.8.0-fkOTaxTD7BIHmfqCE2iLl
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  e7e19f8ebf9b35c24a68d106a9c3d225
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-prettyprint-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.8.0-fkOTaxTD7BIHmfqCE2iLl
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-2Z7fTrN8LMzABCDpsj0YeJ array-0.5.6.0
    base-4.18.2.1 colour-2.3.7-KkFw92GKKvW2X4RWChhdIQ mtl-2.3.1
    path-0.9.6-K5hbh6jRMp4Gg5XJ5U79y
    rio-0.1.24.0-LIdH8BP1lqeJDbEYbX1EDK text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

